Article class

Annotations
  • @freezed

Constructors

Article({@JsonKey.new(name: 'articleId', required: true) required String articleId, @JsonKey.new(name: 'title', required: true) required String title, @JsonKey.new(name: 'description', required: true) required String description, String? body, @JsonKey.new(name: 'icon') required FBIcon? icon, String? parentId, @JsonKey.new(name: 'helpCenterId', required: true) required String helpCenterId, @JsonKey.new(name: 'organizationId', required: true) required String organizationId, @JsonKey.new(name: 'state', defaultValue: 'live') required String state, @JsonKey.new(name: 'locale', required: true) required String locale, required DateTime createdAt, required DateTime updatedAt, @JsonKey.new(name: 'slug', required: true) required String slug, @JsonKey.new(name: 'featurebaseUrl', required: true) required String featurebaseUrl, String? externalUrl, @JsonKey.new(name: 'isDraftDiffersFromLive', defaultValue: false) required bool isDraftDiffersFromLive, @JsonKey.new(name: 'isPublished', defaultValue: true) required bool isPublished, @JsonKey.new(name: 'author', required: true) required Author author, @JsonKey.new(name: 'availableLocales', required: true) required List<String> availableLocales, @JsonKey.new(name: 'publishedLocales', required: true) required List<String> publishedLocales})
const
factory
Article.fromJson(Map<String, Object?> json)
factory

Properties

articleId String
The article's unique ID.
no setterinherited
author Author
Author of the article
no setterinherited
availableLocales List<String>
An array of available locales for the article.
no setterinherited
body String?
The HTML content of the article.
no setterinherited
copyWith → $ArticleCopyWith<Article>
Create a copy of Article with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt DateTime
The date when the article was created.
no setterinherited
description String
A brief description of the article.
no setterinherited
externalUrl String?
The external URL for the article.
no setterinherited
featurebaseUrl String
The Featurebase URL for the article.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
helpCenterId String
The ID of the help center this article belongs to.
no setterinherited
icon FBIcon?
The icon of the article.
no setterinherited
isDraftDiffersFromLive bool
Indicates whether the draft version differs from the live published version.
no setterinherited
isPublished bool
Indicates whether the article is published.
no setterinherited
locale String
The locale of the article.
no setterinherited
organizationId String
The ID of the organization that the article belongs to.
no setterinherited
parentId String?
The ID of the parent collection, if any.
no setterinherited
publishedLocales List<String>
An array of locales in which the article is published.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
The URL-friendly slug of the article.
no setterinherited
state String
The state of the article, either "live" or "draft".
no setterinherited
title String
The title of the article.
no setterinherited
updatedAt DateTime
The date when the article was last updated.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Article to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited