FeaturebaseApi class

Inheritance

Constructors

FeaturebaseApi.from({String apiKey = "token"})

Properties

apiKey String
no setterinherited
changelog ChangelogEnd
no setterinherited
dio → Dio
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
helpCenter HelpCenterEnd
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited