HelpCenterEnd class

Inheritance

Constructors

HelpCenterEnd(FeaturebaseApiBase api)

Properties

dio → Dio
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArticle(String id) Future<Article>
Get Article by ID
getSingleHelpCenter(String id) Future<HelpCenter>
Get a Single Help Center
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited