ChangelogEnd class
- Inheritance
-
- Object
- EndpointBase
- ChangelogEnd
Constructors
Properties
- dio → Dio
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
{String locale = 'en', int page = 1, String? id, String? q, List< String> ? categories, int limit = 10, String state = 'live'}) → Future<ResultsPagination< Changelog> > - Get changelogs
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited